@@ -1082,7 +1082,7 @@ class TaxableMixin(object):
             taxable_lines = [_TaxableLine(*params)
                 for params in self.taxable_lines]
             for line in taxable_lines:
-                l_taxes = Tax.compute(line.taxes, line.unit_price,
+                l_taxes = Tax.compute(Tax.browse(line.taxes), line.unit_price,
                     line.quantity, self.tax_date)
                 for tax in l_taxes:
                     taxline = self._compute_tax_line(**tax)
@@ -1132,7 +1132,7 @@ class TaxLine(ModelSQL, ModelView):
 
     @fields.depends('_parent_move_line.account', 'move_line')
     def on_change_with_company(self, name=None):
-        if self.move_line:
+        if self.move_line and self.move_line.account:
             return self.move_line.account.company.id
 
     def get_rec_name(self, name):
